==========
Intake-esm
==========


`Intake-esm` provides functionality to build and load `intake <https://intake.readthedocs.io/en/latest/>`_ catalogs
for earth system data holdings produced by projects such as CMIP, CESM.


Feedback
--------

If you encounter any errors or problems with **intake-esm**,
please open an issue at the GitHub `main repository <http://github.com/NCAR/intake-esm>`_.


.. toctree::
   :maxdepth: 2
   :caption: Documentation Contents

   notebooks/overview.ipynb
   installation
   notebooks/cmip5.ipynb
   notebooks/cesm.ipynb
   notebooks/mpige.ipynb
   notebooks/gmet.ipynb
   notebooks/era5.ipynb
   api
   cli
   configuration
   contributing
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
